"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OnMod = void 0;
class OnMod {
    constructor(page, browser, options, ev) {
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
    }
    /**
     * Execute a page evaluation with error handling.
     */
    async safeEvaluate(evaluateFn) {
        try {
            await this.page.evaluate(evaluateFn);
        }
        catch (error) {
            console.error('Evaluation error:', error);
        }
    }
    /**
     * Listen to interface changes.
     */
    interfaceChange() {
        this.safeEvaluate(async () => {
            const getData = () => ({
                displayInfo: window.Store.Stream.displayInfo,
                mode: window.Store.Stream.mode,
                info: window.Store.Stream.info,
            });
            const triggerChange = () => window.interfaceChange(getData());
            window.Store.Stream.on('change:info change:displayInfo change:mode', triggerChange);
            triggerChange();
        });
    }
    /**
     * Listen to deleted messages.
     */
    newDeleteMessage() {
        this.safeEvaluate(async () => {
            window.Store.Msg.on('remove remove_msgs', async (deletedMessage) => {
                if (deletedMessage) {
                    const serialized = await API.serializeMessageObj(deletedMessage);
                    window.newDeleteMessage(serialized);
                }
            });
        });
    }
    /**
     * Listen to edited messages.
     */
    newEditMessage() {
        this.safeEvaluate(async () => {
            window.Store.Msg.on('change:body', async (editedMessage) => {
                if (!editedMessage)
                    return;
                const serialized = await API.serializeMessageObj(editedMessage);
                if (editedMessage.body !== undefined) {
                    window.newEditMessage(serialized);
                }
                else {
                    window.newDeleteMessage(serialized);
                }
            });
        });
    }
    /**
     * Listen to new messages.
     */
    newMessage() {
        this.safeEvaluate(async () => {
            window.Store.Msg.on('add', async (newMessage) => {
                if (newMessage === null || newMessage === void 0 ? void 0 : newMessage.isNewMsg) {
                    const serialized = await API.serializeMessageObj(newMessage);
                    window.newMessage(serialized);
                }
            });
        });
    }
    /**
     * Listen to reaction messages.
     */
    onReactionMessage() {
        this.safeEvaluate(async () => {
            window.Store.Reactions.on('add', (reaction) => {
                reaction.reactions.on('add remove', async (...eventArgs) => {
                    const [emoji, collections, type] = eventArgs;
                    const serialized = await API.serializeReactions(emoji, collections, type);
                    window.onReactionMessage(serialized);
                });
            });
        });
    }
    /**
     * Listen to introductory reactions.
     */
    onIntroReactionMessage() {
        this.safeEvaluate(async () => {
            window.Store.Reactions.on('add', async (...eventArgs) => {
                const [emoji, , type] = eventArgs;
                const serialized = await API.serializeIntroReactions(emoji, type);
                if (!Array.isArray(serialized)) {
                    window.onIntroReactionMessage(serialized);
                }
            });
        });
    }
    /**
     * Listen to message acknowledgment (read receipt).
     */
    newOnAck() {
        this.safeEvaluate(async () => {
            window.Store.Msg.on('change:ack', (ackMessage) => {
                if (ackMessage) {
                    window.newOnAck(ackMessage);
                }
            });
        });
    }
}
exports.OnMod = OnMod;
//# sourceMappingURL=on-wpp.js.map